@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, 2010-2011, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -27,16 +27,17 @@
 #ifndef AUDIOFILE_H
 #define AUDIOFILE_H
 
-#include <sys/types.h>
 #include <aupvlist.h>
+#include <stdint.h>
+#include <sys/types.h>
 
 #define LIBAUDIOFILE_MAJOR_VERSION 0
-#define LIBAUDIOFILE_MINOR_VERSION 2
+#define LIBAUDIOFILE_MINOR_VERSION 3
+#define LIBAUDIOFILE_MICRO_VERSION 3
 
 #ifdef __cplusplus
-extern "C"
-{
-#endif /* __cplusplus */
+extern "C" {
+#endif
 
 typedef struct _AFvirtualfile AFvirtualfile;
 
@@ -44,8 +45,23 @@ typedef struct _AFfilesetup *AFfilesetup;
 typedef struct _AFfilehandle *AFfilehandle;
 typedef void (*AFerrfunc)(long, const char *);
 
+// Define AFframecount and AFfileoffset as 64-bit signed integers.
+#if defined(__FreeBSD__) || \
+	defined(__DragonFly__) || \
+	defined(__NetBSD__) || \
+	defined(__OpenBSD__) || \
+	defined(__APPLE__) || \
+	defined(__sgi) || \
+	(defined(__linux__) && defined(__LP64__))
+// BSD and IRIX systems define off_t as a 64-bit signed integer.
+// Linux defines off_t as a 64-bit signed integer in LP64 mode.
 typedef off_t AFframecount;
 typedef off_t AFfileoffset;
+#else
+// For all other systems, use int64_t.
+typedef int64_t AFframecount;
+typedef int64_t AFfileoffset;
+#endif
 
 #define AF_NULL_FILESETUP	((struct _AFfilesetup *) 0)
 #define AF_NULL_FILEHANDLE	((struct _AFfilehandle *) 0)
@@ -82,7 +98,17 @@ enum
 	AF_FILE_NEXTSND = 3,
 	AF_FILE_WAVE = 4,
 	AF_FILE_BICSF = 5,
-	AF_FILE_IRCAM = AF_FILE_BICSF
+	AF_FILE_IRCAM = AF_FILE_BICSF,
+	AF_FILE_MPEG1BITSTREAM = 6,	/* not implemented */
+	AF_FILE_SOUNDDESIGNER1 = 7,	/* not implemented */
+	AF_FILE_SOUNDDESIGNER2 = 8,	/* not implemented */
+	AF_FILE_AVR = 9,
+	AF_FILE_IFF_8SVX = 10,
+	AF_FILE_SAMPLEVISION = 11,	/* not implemented */
+	AF_FILE_VOC = 12,
+	AF_FILE_NIST_SPHERE = 13,
+	AF_FILE_SOUNDFONT2 = 14,	/* not implemented */
+	AF_FILE_CAF = 15
 };
 
 enum
@@ -166,8 +192,11 @@ enum
 	AF_COMPRESSION_G726 = 517,
 	AF_COMPRESSION_G728 = 518,
 	AF_COMPRESSION_DVI_AUDIO = 519,
+	AF_COMPRESSION_IMA = AF_COMPRESSION_DVI_AUDIO,
 	AF_COMPRESSION_GSM = 520,
-	AF_COMPRESSION_FS1016 = 521
+	AF_COMPRESSION_FS1016 = 521,
+	AF_COMPRESSION_DV = 522,
+	AF_COMPRESSION_MS_ADPCM = 523
 };
 
 /* tokens for afQuery() -- see the man page for instructions */
@@ -412,14 +441,14 @@ void afInitFileFormat (AFfilesetup, int format);
 int afGetFileFormat (AFfilehandle, int *version);
 
 /* track */
-void afInitTrackIDs (AFfilesetup, int *trackids, int trackCount);
+void afInitTrackIDs (AFfilesetup, const int *trackids, int trackCount);
 int afGetTrackIDs (AFfilehandle, int *trackids);
 
 /* track data: reading, writng, seeking, sizing frames */
 int afReadFrames (AFfilehandle, int track, void *buffer, int frameCount);
 int afWriteFrames (AFfilehandle, int track, const void *buffer, int frameCount);
 AFframecount afSeekFrame (AFfilehandle, int track, AFframecount frameoffset);
-AFfileoffset afTellFrame (AFfilehandle, int track);
+AFframecount afTellFrame (AFfilehandle, int track);
 AFfileoffset afGetTrackBytes (AFfilehandle, int track);
 float afGetFrameSize (AFfilehandle, int track, int expand3to4);
 float afGetVirtualFrameSize (AFfilehandle, int track, int expand3to4);
@@ -431,21 +460,6 @@ void afInitAESChannelDataTo (AFfilesetup, int track, int willBeData);
 int afGetAESChannelData (AFfilehandle, int track, unsigned char buf[24]);
 void afSetAESChannelData (AFfilehandle, int track, unsigned char buf[24]);
 
-#if 0
-/* track setup format initialized via DMparams */
-/* track format retrieved via DMparams */
-DMstatus afInitFormatParams (AFfilesetup, int track, DMparams *params);
-/* virtual format set via DMparams */
-DMstatus afGetFormatParams (AFfilehandle, int track, DMparams *params);
-/* virtual format retrieved via DMparams */
-DMstatus afSetVirtualFormatParams (AFfilehandle, int track, DMparams *params);
-DMstatus afGetVirtualFormatParams (AFfilehandle, int track, DMparams *params);
-/* conversion/compression params set via DMparams */
-DMstatus afSetConversionParams (AFfilehandle, int track, DMparams *params);
-/* conversion/compression params retrieved via DMparams */
-DMstatus afGetConversionParams (AFfilehandle, int track, DMparams *params);
-#endif
-
 /* track data: byte order */
 void afInitByteOrder (AFfilesetup, int track, int byteOrder);
 int afGetByteOrder (AFfilehandle, int track);
@@ -462,10 +476,8 @@ void afSetChannelMatrix (AFfilehandle, int track, double *matrix);
 /* track data: sample format and sample width */
 void afInitSampleFormat (AFfilesetup, int track, int sampleFormat,
 	int sampleWidth);
-void afGetSampleFormat (AFfilehandle file, int track, int *sampfmt,
-	int *sampwidth);
-void afGetVirtualSampleFormat (AFfilehandle file, int track, int *sampfmt,
-	int *sampwidth);
+void afGetSampleFormat (AFfilehandle file, int track, int *sampleFormat,
+	int *sampleWidth);
 int afSetVirtualSampleFormat (AFfilehandle, int track,
 	int sampleFormat, int sampleWidth);
 void afGetVirtualSampleFormat (AFfilehandle, int track,
@@ -527,7 +539,7 @@ void afInitFrameCount (AFfilesetup, int track, AFframecount frameCount);
 AFframecount afGetFrameCount (AFfilehandle file, int track);
 
 /* loop operations */
-void afInitLoopIDs (AFfilesetup, int instid, int ids[], int nids);
+void afInitLoopIDs (AFfilesetup, int instid, const int *ids, int nids);
 int afGetLoopIDs (AFfilehandle, int instid, int loopids[]);
 void afSetLoopMode (AFfilehandle, int instid, int loop, int mode);
 int afGetLoopMode (AFfilehandle, int instid, int loopid);
@@ -549,7 +561,7 @@ void afSetLoopTrack (AFfilehandle, int instid, int loopid, int trackid);
 int afGetLoopTrack (AFfilehandle, int instid, int loopid);
 
 /* marker operations */
-void afInitMarkIDs (AFfilesetup, int trackid, int *ids, int nids);
+void afInitMarkIDs (AFfilesetup, int trackid, const int *ids, int nids);
 int afGetMarkIDs (AFfilehandle file, int trackid, int markids[]);
 void afSetMarkPosition (AFfilehandle file, int trackid, int markid,
 	AFframecount markpos);
@@ -561,7 +573,7 @@ char *afGetMarkName (AFfilehandle file, int trackid, int markid);
 char *afGetMarkComment (AFfilehandle file, int trackid, int markid);
 
 /* instrument operations */
-void afInitInstIDs (AFfilesetup, int *ids, int nids);
+void afInitInstIDs (AFfilesetup, const int *ids, int nids);
 int afGetInstIDs (AFfilehandle file, int *instids);
 void afGetInstParams (AFfilehandle file, int instid, AUpvlist pvlist,
 	int nparams);
@@ -571,18 +583,18 @@ long afGetInstParamLong (AFfilehandle file, int instid, int param);
 void afSetInstParamLong (AFfilehandle file, int instid, int param, long value);
 
 /* miscellaneous data operations */
-void afInitMiscIDs (AFfilesetup, int *ids, int nids);
+void afInitMiscIDs (AFfilesetup, const int *ids, int nids);
 int afGetMiscIDs (AFfilehandle, int *ids);
 void afInitMiscType (AFfilesetup, int miscellaneousid, int type);
 int afGetMiscType (AFfilehandle, int miscellaneousid);
 void afInitMiscSize (AFfilesetup, int miscellaneousid, int size);
 int afGetMiscSize (AFfilehandle, int miscellaneousid);
-int afWriteMisc (AFfilehandle, int miscellaneousid, void *buf, int bytes);
+int afWriteMisc (AFfilehandle, int miscellaneousid, const void *buf, int bytes);
 int afReadMisc (AFfilehandle, int miscellaneousid, void *buf, int bytes);
 int afSeekMisc (AFfilehandle, int miscellaneousid, int offset);
 
 #ifdef __cplusplus
 }
-#endif /* __cplusplus */
+#endif
 
 #endif /* AUDIOFILE_H */
